dot-prepare_data: Apply log2 normalisation if the data appear to be on a linear...

.prepare_dataR Documentation

Apply log2 normalisation if the data appear to be on a linear scale

Description

Apply log2 normalisation if the data appear to be on a linear scale

Usage

.prepare_data(dataframe, con1, con2, exp1, exp2)

Arguments

dataframe

Numeric data.frame.

con1, con2, exp1, exp2

Column indices.

Value

A list with dataframe (possibly log2-transformed), con, exp, con_m, exp_m, log2FC, and logical log_transformed.


DGEAR documentation built on July 3, 2026, 9:07 a.m.