dot-resolve_symbols: Resolve gene symbols from row names or an optional annotation...

.resolve_symbolsR Documentation

Resolve gene symbols from row names or an optional annotation table

Description

Resolve gene symbols from row names or an optional annotation table

Usage

.resolve_symbols(dataframe, annot_df = NULL)

Arguments

dataframe

Gene expression data.frame (rows = probes/genes).

annot_df

Optional annotation data.frame with columns ID and one of Gene.Symbol / Gene.symbol. When NULL (the default) row names of dataframe are used as gene identifiers.

Value

A character vector of gene symbols the same length as nrow(dataframe).


DGEAR documentation built on July 3, 2026, 9:07 a.m.