| .resolve_symbols | R Documentation |
Resolve gene symbols from row names or an optional annotation table
.resolve_symbols(dataframe, annot_df = NULL)
dataframe |
Gene expression data.frame (rows = probes/genes). |
annot_df |
Optional annotation data.frame with columns |
A character vector of gene symbols the same length as
nrow(dataframe).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.