| perform_h_test | R Documentation |
Computes a modified t-statistic (sometimes called "Half's t-test") that uses only the control standard deviation in its denominator, applies BH correction, and returns a results table together with the list of significant DEGs.
perform_h_test(
dataframe,
con1,
con2,
exp1,
exp2,
alpha = 0.05,
annot_df = NULL
)
dataframe |
A numeric matrix or data.frame of gene expression values (rows = genes, columns = samples). Values are automatically log2- transformed when they appear to be on a linear / intensity scale. |
con1 |
Integer. Index of the first control column. |
con2 |
Integer. Index of the last control column. |
exp1 |
Integer. Index of the first experiment column. |
exp2 |
Integer. Index of the last experiment column. |
alpha |
Numeric significance threshold for BH-adjusted p-values
(default |
annot_df |
Optional annotation data.frame with columns |
A named list:
Data.frame with columns G_Symbol, log2FC,
statistic, p.value, BH, fdr.
Data.frame of significant gene identifiers.
library(DGEAR)
data("gene_exp_data")
result <- perform_h_test(dataframe = gene_exp_data,
con1 = 1, con2 = 10,
exp1 = 11, exp2 = 20)
head(result$Table)
result$DEGs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.