powered by
Function for Half's-T-Test Analysis
perform_h_test(con, exp, alpha = 0.05, FC)
A data frame containing values for statistic score, p-values etc for each gene being tested.
A data frame or matrix containing the expression values for the control.
A data frame or matrix containing the expression values for the experiment.
Value of significance level ranging from 0 to 1 (default = 0.05 states 5 % significance).
An array or list containing fold change values for each gene, calculated by
library(DGEAR) data("gene_exp_data") data = read_and_preprocess_data(datafile = gene_exp_data, con1=1,con2=10,exp1=11,exp2=20) perform_h_test(con= data$con, exp= data$exp, FC = data$FC)
Run the code above in your browser using DataLab